/**************************************************************************
 *
 * Filename:    SimpleTrigger.java
 *
 * Copyright:   Pico Technology Limited 2011
 *
 * Author:      HSM
 *
 * Description:
 *      This class provides an object representation of a SimpleTrigger 
 *      structure.
 *	
 * History:
 *     Aug11 HSM Created
 *
 * Revision Info: "file %n date %f revision %v"
 *						""
 *
 ***************************************************************************/
package com.picotech.picoscope;

import com.picotech.picoscope.ps2000.PS2000Data;
import com.picotech.picoscope.ps2000.PS2000Data.EnPS2000Channel;

/**
 * This class contains information for a simple trigger.
 * @author hitesh
 */
public class SimpleTrigger 
{
    private PS2000Data.EnPS2000Channel channel;
    float threshold;
    short direction;
    float delay;

    /**
     * Constructor to create a new Simple Trigger object
     * 
     * @param st_channel - The channel on which to trigger
     * @param st_threshold - The threshold voltage (mV)
     * @param st_direction - The direction
     * @param st_delay - The delay
     */
    public SimpleTrigger(EnPS2000Channel st_channel, float st_threshold, 
            short st_direction, float st_delay) 
    {
        
        channel = st_channel;
        threshold = st_threshold;
        direction = st_direction;
        delay = st_delay;
    }
    
    // Getters and Setters

    /**
     * 
     * @return 
     */
    public EnPS2000Channel getChannel() 
    {
        return channel;
    }

    /**
     * 
     * @param st_channel 
     */
    public void setChannel(EnPS2000Channel st_channel) 
    {
        channel = st_channel;
    }

    /**
     * 
     * @return 
     */
    public float getDelay() 
    {
        return delay;
    }

    /**
     * 
     * @param st_delay 
     */
    public void setDelay(float st_delay) 
    {
        delay = st_delay;
    }

    /**
     * 
     * @return 
     */
    public short getDirection() 
    {
        return direction;
    }

    /**
     * 
     * @param st_direction 
     */
    public void setDirection(short st_direction) 
    {
        direction = st_direction;
    }

    /**
     * 
     * @return 
     */
    public float getThreshold() 
    {
        return threshold;
    }
    
    /**
     * 
     * @param st_threshold 
     */
    public void setThreshold(float st_threshold) 
    {
        this.threshold = st_threshold;
    }

}
