/**************************************************************************
 *
 * Filename:    PS2000.java
 *
 * Copyright:   Pico Technology Limited 2013
 *
 * Author:      HSM
 *
 * Description:
 *   This is a console-mode program that demonstrates how to use the
 *   PS2000 driver, available for the PS2104/5, and PS2203, 2204 and 2205.
 * 
 *   The example supports the following:
 * 
 *      - Immediate Block
 *      - Triggered block
 *      - Signal Generator
 *
 * Examples:
 *    
 * To build this application open the project in Netbeans IDE 7.0 or later,
 * and ensure that the JDK version is 1.7.0 or greater. 
 *	
 *
 * History:
 *     27Jul11 HSM Created
 *
 * Revision Info: "file %n date %f revision %v"
 *						""
 *
 ***************************************************************************/
package com.picotech.picoscope.ps2000;

//import com.picotech.picoscope.AdvancedTrigger;
import com.picotech.picoscope.SimpleTrigger;
import com.picotech.picoscope.ConsoleReader;
import com.picotech.picoscope.ChannelSettings;
import com.picotech.picoscope.PicoScope;
import com.picotech.picoscope.TimeIndisposed;
import com.picotech.picoscope.TimebaseInfo;
import com.picotech.picoscope.TimesAndValues;
import com.picotech.picoscope.util.AdcMvConverter;
import com.picotech.picoscope.util.DataFileWriter;
import com.picotech.picoscope.TimeDefinitions;
import com.picotech.picoscope.VoltageDefinitions;
import com.picotech.picoscope.util.AbortButtonJFrameRunnable;

import java.io.IOException;

import javax.swing.SwingUtilities;


/**
 *
 * @author hitesh
 */
public class PS2000 extends PicoScope
{
    

    ////////////////////////////////////////////////////////////////////////////
    //
    // Class variables
    //
    ////////////////////////////////////////////////////////////////////////////

    private boolean unitOpened;
    private boolean scaleToMv;
    private boolean isPS21xxLightOn;   
            
    private boolean isDebugModeOn;
            
    private short timebase;
    
    private DataFileWriter dataFileWriter;
    private UnitModel unitModel;
    private PS2000JNIWrapAccessor ps2000JniWrapAccessor;
    
    //private Scanner consoleScanner;
    private TimesAndValues timesAndValues;
    
    
    ////////////////////////////////////////////////////////////////////////////
    //
    // Constructor
    //
    ////////////////////////////////////////////////////////////////////////////
    
    /**
     * 
     */
    public PS2000() 
    {
        super();
        
        unitOpened = false;
        scaleToMv = true;
        isPS21xxLightOn = false;
        isDebugModeOn = true;
        
        

        //Set default timebase value
        timebase = 8;
        
        //consoleScanner = new Scanner(System.in); 
        
        // Open Unit
        System.out.println("Opening the device...");
        
        // Create new instance of class to access wrapper
        ps2000JniWrapAccessor = new PS2000JNIWrapAccessor();
        
        // Object to hold information on the unit
        unitModel = new UnitModel();
        
        // Assign the handle
        unitModel.setHandle(ps2000JniWrapAccessor.ps2000OpenUnit());
        
        if(unitModel.getHandle() > 0)
        {
            System.out.println("handle: " + unitModel.getHandle());
            System.out.println();
            
            unitOpened = true;
        }
        else 
        {
            System.out.println("Unable to open device - exiting application.");
            System.exit(1);
        }
        
        // Obtain information on the Unit
        getInfo();
        
        
    }
    
    

    /**
     * 
     * @param unitOpened 
     */
    public void setUnitOpened(boolean unit_opened) 
    {
        unitOpened = unit_opened;
    }

    /**
     * 
     * @return 
     */
    public boolean isUnitOpened() 
    {
        return unitOpened;
    }

    /**
     * 
     * @return 
     */
    public PS2000JNIWrapAccessor getPs2000JniWrapAccessor() 
    {
        return ps2000JniWrapAccessor;
    }

    /**
     * 
     * @return 
     */
    public UnitModel getUnitModel() 
    {
        return unitModel;
    }

    public boolean isScaleToMv() 
    {
        return scaleToMv;
    }

    public void setScaleToMv(boolean scale_to_mv) 
    {
        scaleToMv = scale_to_mv;
    }

//    protected Scanner getConsoleScanner() 
//    {
//        return consoleScanner;
//    }

    public boolean isDebugModeOn() 
    {
        return isDebugModeOn;
    }

    public void setIsDebugModeOn(boolean is_debug_mode_on) 
    {
        isDebugModeOn = is_debug_mode_on;
    }

    public boolean isPS21xxLightOn() 
    {
        return isPS21xxLightOn;
    }

    public void setIsPS21xxLightOn(boolean is_ps21xx_light_on) 
    {
        isPS21xxLightOn = is_ps21xx_light_on;
    }
    
    /**
     * Obtains information for the connected unit.
     */
    private void getInfo()
    {
        String[] description  = { "Driver Version", "USB Version", 
                                    "Hardware Version", "Variant Info",
                                     "Serial", "Calibration Date", 
                                     "Error Code", "Kernel Driver Version" };
        
        // String Builder to create String that is 80 characters long
        //StringBuilder line_builder = new StringBuilder(80);
        
        // String to accept information
        String unit_info_line = "";

        // PicoScope 2000 Series model variant
        int variant = 0;
        
        if(isUnitOpened() == true)
        {
            System.out.println("=== Unit Information ===");
            
            for(int i = 0; i < 7; i = i + 1)
            {
                
                // Call ps2000_get_unit_info 
                unit_info_line = getPs2000JniWrapAccessor().ps2000GetInfo(getUnitModel().getHandle(), (short) i);
                
                // Variant info
                if(i == 3)
                {
                    variant = Integer.parseInt(unit_info_line);                    
                }
                
                if(i != 6)
                {
                    System.out.println(description[i] + ": " + unit_info_line);                
                }
            }
            
            
            // Check the model type
            
            if(variant == PS2000Data.EnPS2000ModelType.MODEL_PS2104.getPS2000ModelType())
            {
                getUnitModel().setModelType(PS2000Data.EnPS2000ModelType.MODEL_PS2104);
                getUnitModel().setFirstRange(PS2000Data.EnPS2000Range.PS2000_100MV);
                getUnitModel().setLastRange(PS2000Data.EnPS2000Range.PS2000_20V);
                getUnitModel().setMaxTimebase(PS2000Data.PS2104_MAX_TIMEBASE);
                getUnitModel().setTimebases(getUnitModel().getMaxTimebase());
                getUnitModel().setNoOfChannels((short) 1);
                getUnitModel().setHasAdvancedTriggering(false);
                getUnitModel().setHasSignalGenerator(false);
                getUnitModel().setHasEts(true);
                getUnitModel().setHasFastStreaming(false);
                
            }
            else if(variant == PS2000Data.EnPS2000ModelType.MODEL_PS2105.getPS2000ModelType())
            {
                getUnitModel().setModelType(PS2000Data.EnPS2000ModelType.MODEL_PS2105);
                getUnitModel().setFirstRange(PS2000Data.EnPS2000Range.PS2000_100MV);
                getUnitModel().setLastRange(PS2000Data.EnPS2000Range.PS2000_20V);
                getUnitModel().setMaxTimebase(PS2000Data.PS2105_MAX_TIMEBASE);
                getUnitModel().setTimebases(getUnitModel().getMaxTimebase());
                getUnitModel().setNoOfChannels((short) 1);
                getUnitModel().setHasAdvancedTriggering(false);
                getUnitModel().setHasSignalGenerator(false);
                getUnitModel().setHasEts(true);
                getUnitModel().setHasFastStreaming(false);
            }
            else if(variant == PS2000Data.EnPS2000ModelType.MODEL_PS2202.getPS2000ModelType())
            {
                getUnitModel().setModelType(PS2000Data.EnPS2000ModelType.MODEL_PS2202);
                getUnitModel().setFirstRange(PS2000Data.EnPS2000Range.PS2000_100MV);
                getUnitModel().setLastRange(PS2000Data.EnPS2000Range.PS2000_20V);
                getUnitModel().setMaxTimebase(PS2000Data.PS2200_MAX_TIMEBASE);
                getUnitModel().setTimebases(getUnitModel().getMaxTimebase());
                getUnitModel().setNoOfChannels((short) 2);
                getUnitModel().setHasAdvancedTriggering(false);
                getUnitModel().setHasSignalGenerator(false);
                getUnitModel().setHasEts(false);
                getUnitModel().setHasFastStreaming(false);
            }
            else if(variant == PS2000Data.EnPS2000ModelType.MODEL_PS2203.getPS2000ModelType())
            {
                getUnitModel().setModelType(PS2000Data.EnPS2000ModelType.MODEL_PS2203);
                getUnitModel().setFirstRange(PS2000Data.EnPS2000Range.PS2000_50MV);
                getUnitModel().setLastRange(PS2000Data.EnPS2000Range.PS2000_20V);
                getUnitModel().setMaxTimebase(PS2000Data.PS2000_MAX_TIMEBASE);
                getUnitModel().setTimebases(getUnitModel().getMaxTimebase());
                getUnitModel().setNoOfChannels((short) 2);
                getUnitModel().setHasAdvancedTriggering(true);
                getUnitModel().setHasSignalGenerator(true);
                getUnitModel().setHasEts(true);
                getUnitModel().setHasFastStreaming(true);
            }
            else if(variant == PS2000Data.EnPS2000ModelType.MODEL_PS2204.getPS2000ModelType())
            {
                getUnitModel().setModelType(PS2000Data.EnPS2000ModelType.MODEL_PS2204);
                getUnitModel().setFirstRange(PS2000Data.EnPS2000Range.PS2000_50MV);
                getUnitModel().setLastRange(PS2000Data.EnPS2000Range.PS2000_20V);
                getUnitModel().setMaxTimebase(PS2000Data.PS2000_MAX_TIMEBASE);
                getUnitModel().setTimebases(getUnitModel().getMaxTimebase());
                getUnitModel().setNoOfChannels((short) 2);
                getUnitModel().setHasAdvancedTriggering(true);
                getUnitModel().setHasSignalGenerator(true);
                getUnitModel().setHasEts(true);
                getUnitModel().setHasFastStreaming(true);
            }
            else if(variant == PS2000Data.EnPS2000ModelType.MODEL_PS2205.getPS2000ModelType())
            {
                getUnitModel().setModelType(PS2000Data.EnPS2000ModelType.MODEL_PS2205);
                getUnitModel().setFirstRange(PS2000Data.EnPS2000Range.PS2000_50MV);
                getUnitModel().setLastRange(PS2000Data.EnPS2000Range.PS2000_20V);
                getUnitModel().setMaxTimebase(PS2000Data.PS2000_MAX_TIMEBASE);
                getUnitModel().setTimebases(getUnitModel().getMaxTimebase());
                getUnitModel().setNoOfChannels((short) 2);
                getUnitModel().setHasAdvancedTriggering(true);
                getUnitModel().setHasSignalGenerator(true);
                getUnitModel().setHasEts(true);
                getUnitModel().setHasFastStreaming(true);
            }
            else
            {
                System.out.println("Unit not supported.");
            }
            
            //Create Channel Settings
            ChannelSettings ch_settings_a = new ChannelSettings((short) 1, 
                    (short )getUnitModel().getLastRange().ordinal(), false, PS2000Data.BUFFER_SIZE);
            
            ChannelSettings ch_settings_b = new ChannelSettings((short) 1, 
                    (short) getUnitModel().getLastRange().ordinal(), false, PS2000Data.BUFFER_SIZE);
            
            // Add to unitModel object
            ChannelSettings[] ch_settings = new ChannelSettings[getUnitModel().getNoOfChannels()];
            
            ch_settings[PS2000Data.EnPS2000Channel.PS2000_CHANNEL_A.ordinal()] = ch_settings_a;
            ch_settings[PS2000Data.EnPS2000Channel.PS2000_CHANNEL_B.ordinal()] = ch_settings_b;
            
            unitModel.setChannelSettings(ch_settings);

        }
        else
        {
            System.out.println("Unit Not Opened.");
            
            //Call ps2000_get_unit_info
            unit_info_line = getPs2000JniWrapAccessor().ps2000GetInfo(getUnitModel().getHandle(), (short) 5);
            
            System.out.println(description[5] + ": " + unit_info_line);
            
            getUnitModel().setModelType(PS2000Data.EnPS2000ModelType.MODEL_NONE);
            getUnitModel().setFirstRange(PS2000Data.EnPS2000Range.PS2000_100MV);
            getUnitModel().setLastRange(PS2000Data.EnPS2000Range.PS2000_20V);
            getUnitModel().setTimebases(PS2000Data.PS2105_MAX_TIMEBASE);
            getUnitModel().setNoOfChannels((short) 1);
            
            //Set unit opened
            setUnitOpened(false);
        }
        
        System.out.println();
    }
    
    
    // Methods to undertake user actions
    
    public void setTimebase()
    {
        TimebaseInfo timebase_info = new TimebaseInfo();
        
        System.out.println("Available timebases:");
        System.out.println();
        
        /* See what ranges are available...*/
     
        short over_sample = 1;
        
        for (int i = 0; i < unitModel.getTimebases() ; i = i + 1)
        {
            ps2000JniWrapAccessor.ps2000GetTimebase(unitModel.getHandle(), 
                    (short) i, PS2000Data.BUFFER_SIZE, over_sample, timebase_info);

            if ( timebase_info.getTimeInterval() > 0 )
            {
                /*
                System.out.println(i + " -> " + timebase_info.getTimeInterval() +
                        " " + AdcMvConverter.adc_units(timebase_info.getTimeUnits()) + 
                        " " + timebase_info.getTimeUnits());
                 * 
                 */
                
                System.out.println(i + " -> " + timebase_info.getTimeInterval() +
                        " " + AdcMvConverter.adc_units(timebase_info.getTimeUnits()));
            }
        }

        System.out.println();
        
        // Ask the user to select a timebase

        System.out.print( "Please select timebase: " );
        System.out.println();
        
        do
        {
            timebase = getConsoleScanner().nextShort();
        } 
        while ((timebase < 0) || (timebase >= unitModel.getTimebases()));
        
        ps2000JniWrapAccessor.ps2000GetTimebase(unitModel.getHandle(), timebase, 
                PS2000Data.BUFFER_SIZE, over_sample, timebase_info);
        
        System.out.println("Timebase " + timebase + " - " + 
                timebase_info.getTimeInterval() + 
                AdcMvConverter.adc_units(timebase_info.getTimeUnits())); 
        
        if(isDebugModeOn == true)
        {
            System.out.println("Max samples: " + timebase_info.getMaxSamples());
            System.out.println("Time interval: " + timebase_info.getTimeInterval());
            System.out.println("Time units: " + timebase_info.getTimeUnits());
        }
    }
    
    /**
     * Prompts the User to select the voltage range for channels on the device.
     */
    public void setVoltages()
    {
        //See what ranges are available...
            
        for (int i = unitModel.getFirstRange().ordinal(); i <= unitModel.getLastRange().ordinal(); i = i + 1 )
        {
            System.out.println(i + " -> " + PS2000Data.inputRanges[i] + "mV");
              
        }
        
        System.out.println();

        // Ask the user to select a range
  
        for (int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
	{
            System.out.println("Specify voltage range (" + 
                    unitModel.getFirstRange().ordinal() + ".." + 
                    unitModel.getLastRange().ordinal() + "):");
            
            System.out.println("99 - switches channel off.");

            char channel_char = (char) ('A' + ch);
            
            System.out.print("Channel " + channel_char + ": ");

            // Default value
            short input_range = (short) unitModel.getFirstRange().ordinal();
            
            // while the range is not 99 and is not less than the first range or 
            // greater than the last range value. 
            do
            {
                input_range = getConsoleScanner().nextShort();
                unitModel.getChannelSettings()[ch].setRange(input_range);

            } while (input_range != 99 && 
                    (input_range < unitModel.getFirstRange().ordinal() 
                    || input_range > unitModel.getLastRange().ordinal()));

            // Set channel on or off
            if(input_range != 99)
            {
                System.out.println(" - " + PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()] + "mV");
                unitModel.getChannelSettings()[ch].setEnabled(true);
            }
            else
            {
                System.out.println( "Channel Switched off.");
                unitModel.getChannelSettings()[ch].setEnabled(false);
            }
        } 
    }
   
    public void setDefaults()
    {   
        System.out.println("Setting Channel defaults...");
        System.out.println();
        
        if(unitModel.getModelType().equals(PS2000Data.EnPS2000ModelType.MODEL_PS2202) == false)
        {
            //Set ETS values
            ps2000JniWrapAccessor.ps2000SetETS(unitModel.getHandle(), 
                    (short) PS2000Data.EnPS2000EtsMode.PS2000_ETS_OFF.ordinal(), (short) 0, (short) 0);
        }
        
        char channel_char_A = 'A';
        
        // Set the channels
        for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
        {
            ps2000JniWrapAccessor.ps2000SetChannel(unitModel.getHandle(), 
                    (short) ch,
                    unitModel.getChannelSettings()[ch].isEnabledValue(),
                    unitModel.getChannelSettings()[ch].getDcCoupled(), 
                    unitModel.getChannelSettings()[ch].getRange());

            System.out.println("Channel " + (char) (channel_char_A + ch) + ": ");
            
            
            if(unitModel.getChannelSettings()[ch].isEnabled() == true)
            {
                unitModel.getChannelSettings()[ch].printChannelInformation();
            }
            else
            {
                System.out.println("Channel disabled.");
            }
            
            System.out.println();
        }
        
    }
    
    public void setPS21xxLight(short handle, boolean state)
    {
        short ps21xx_light_state;
        
        if(state == true)
        {
            ps21xx_light_state = ps2000JniWrapAccessor.ps2000SetLight(handle, (short) 1); 
            
        }
        else
        {
            ps21xx_light_state = ps2000JniWrapAccessor.ps2000SetLight(handle, (short) 0); 
            
        }
        
        if(ps21xx_light_state == 0)
        {
            System.out.println("Call to switch on/off light failed.");
            setIsPS21xxLightOn(false);
        }
        else
        {
            if(state == true)
            {
                setIsPS21xxLightOn(true);
            }
            else
            {
                setIsPS21xxLightOn(false);
            }
        }
    }
    
    /**
     * Collect_block_immediate
     * this function demonstrates how to collect a single block of data
     * from the unit (start collecting immediately)
     */
    public void collectBlockImmediate()
    {

        System.out.println("Collect block immediate...");
        System.out.println("Press ENTER or a key + ENTER to start:");
                
        getAnyKeyInput();
         
        //System.out.println();        
        
        setDefaults();

        short auto_trigger_ms = 0;

        // Trigger disabled
        short trigger_status = ps2000JniWrapAccessor.ps2000SetTrigger(unitModel.getHandle(), 
                (short) PS2000Data.EnPS2000Channel.PS2000_NONE.ordinal(), 
                (short) 0, (short) PS2000Data.En2000TriggerDirection.PS2000_RISING.ordinal(), 
                (short) 0, auto_trigger_ms);
        
        /*  
         * Find the maximum number of samples, the time interval (in time_units),
         * the most suitable time units, and the maximum oversample at the current timebase
         * 
        */ 
        
        short block_im_oversample = 1;
        
        int no_of_samples = PS2000Data.BUFFER_SIZE;
        TimebaseInfo timebase_info = new TimebaseInfo();
        
        // Find a timebase that is in range
        while(ps2000JniWrapAccessor.ps2000GetTimebase(unitModel.getHandle(), 
                timebase, no_of_samples, block_im_oversample, timebase_info) == 0)
        {
            timebase = (short) (timebase + 1);
        }
        
        System.out.println("Timebase: " + timebase + 
                "\t Oversample: " + block_im_oversample);
        
        /* 
         * Start it collecting,
         * then wait for completion
         */
        TimeIndisposed time_indisposed = new TimeIndisposed();
        
        System.out.println("Calling Run Block function...");
        
        ps2000JniWrapAccessor.ps2000RunBlock(unitModel.getHandle(), 
                no_of_samples, timebase, block_im_oversample, time_indisposed);
        
        System.out.println("Wait until device is ready...");
        
        while(ps2000JniWrapAccessor.ps2000Ready(unitModel.getHandle()) == 0)
        {
            try
            {
                Thread.sleep(100);
            }
            catch(InterruptedException ie)
            {
                System.err.println("PS2000::collectBlockImmediate() - "
                        + "sleep interrupted.");
            }
        }
        
        System.out.println("Stopping the device...");
        
        // Stop the device
        ps2000JniWrapAccessor.ps2000Stop(unitModel.getHandle());
        
        /* Should be done now...
        *  get the times (in nanoseconds)
        *  and the values (in ADC counts)
        */
        
        // Object to store data values
        timesAndValues = new TimesAndValues();
        
        System.out.println("Getting times and values...");
        
        ps2000JniWrapAccessor.ps2000GetTimesAndValues(unitModel.getHandle(), 
                timesAndValues, timebase_info.getTimeUnits(), no_of_samples); 
        
        // Retrieve Channel A values
        unitModel.getChannelSettings()[PS2000Data.EnPS2000Channel.PS2000_CHANNEL_A.ordinal()].setValues(timesAndValues.getBufferA());
        
        unitModel.getChannelSettings()[PS2000Data.EnPS2000Channel.PS2000_CHANNEL_B.ordinal()].setValues(timesAndValues.getBufferB());
        
        /* 
         * Print out the first 25 readings,
         *  converting the readings to mV if required
         */
        
        System.out.println("First 25 readings");
        //System.out.println("Value");
        
//        System.out.print("Time (" + AdcMvConverter.adc_units(timebase_info.getTimeUnits()) + ")\t");
//        
//        for(int i = 0; i < unitModel.getNoOfChannels(); i = i + 1)
//        {
//            if(unitModel.getChannelSettings()[i].isEnabled() == true)
//            {
//                System.out.print("Channel " + (char) ('A' + i) + " (");
//                
//                if(scaleToMv == true)
//                {
//                    System.out.print("mV) \t");
//                }
//                else
//                {
//                    System.out.print("ADC) \t");
//                }
//            }
//        }
//        
//        System.out.println();
//        
//        for(int i = 0; i < 25; i = i + 1)
//        {
//            System.out.print(timesAndValues.getTimes()[i] + "\t");
//            
//            //System.out.format("%d \t", timesAndValues.getTimes()[i]);
//            
//            for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
//            {
//                if(unitModel.getChannelSettings()[ch].isEnabled() == true)
//                {
//                    int voltage_range = PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()];
//                    
//                    System.out.print(AdcMvConverter.adc_to_mv(unitModel.getChannelSettings()[ch].getValues()[i], 
//                            voltage_range, scaleToMv) + "\t");
//                    
//                    // System.out.format("%d \t", AdcMvConverter.adc_to_mv(unitModel.getChannelSettings()[ch].getValues()[i], 
//                    // voltage_range, scaleToMv));
//                }
//                
//            }
//            
//            System.out.println();
//            
//        }
//        
//        System.out.println();
        
        printTimeAndDataValues(25, timebase_info);
        
        //TBD - output to file
        dataFileWriter = new DataFileWriter("C:\\Output\\", DataFileWriter.IMMEDIATE_BLOCK, DataFileWriter.FILE_EXTENSION_TXT);

        try 
        {
            dataFileWriter.writeHeaderToFile(unitModel, scaleToMv, 
                AdcMvConverter.adc_units(timebase_info.getTimeUnits()));

            for(int i = 0; i < timesAndValues.getTimes().length; i = i + 1)
            {
                StringBuilder data_line = new StringBuilder();
                data_line.append(Integer.toString(timesAndValues.getTimes()[i]));
                data_line.append("\t");

                for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
                {
                    if(unitModel.getChannelSettings()[ch].isEnabled() == true)
                    {
                        int voltage_range = PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()];
                                
                        int data_value = AdcMvConverter.adc_to_mv(unitModel.getChannelSettings()[ch].getValues()[i], 
                                voltage_range, scaleToMv);

                        data_line.append(Integer.toString(data_value));
                        data_line.append("\t");

                    }

                }
                
                dataFileWriter.writeDataToFile(data_line.toString());
                dataFileWriter.writeNewLineToFile();

            }

            dataFileWriter.closeFile();
        
        } 
        catch (IOException ioe) 
        {
            ioe.printStackTrace();
        }
        
    }
    
    /****************************************************************************
     *
     * Collect_streaming
     *  this function demonstrates how to use streaming.
     *
     * In this mode, you can collect data continuously.
     *
     * This example writes data to disk...
     * don't leave it running too long or it will fill your disk up!
     *
     * Each call to ps2000_get_values returns the readings since the
     * last call
     *
     ****************************************************************************/
    public void collectStreaming()
    {
        System.out.println("Collect streaming...");
        System.out.println("Data is written to disk file (Streaming_[Date]_[Time].txt)");
        System.out.println("Press ENTER to start");
        
        getAnyKeyInput();
        
        setDefaults();
        
        short zero_short = (short) 0;
        
        /* You cannot use triggering for the start of the data... */
        short set_trigger_status = ps2000JniWrapAccessor.ps2000SetTrigger(unitModel.getHandle(), 
                (short) PS2000Data.EnPS2000Channel.PS2000_NONE.getChannelValue(), 
                zero_short, zero_short, zero_short, zero_short);
        
        System.out.println("Set trigger status: " + set_trigger_status);
        
       /* Collect data at 10ms intervals
	* Max BUFFER_SIZE points on each call
	*  (buffer must be big enough for max time between calls
	*
	*  Start it collecting,
	*  then wait for trigger event
	*/
        short streaming_ok = ps2000JniWrapAccessor.ps2000RunStreaming(unitModel.getHandle(), 
                TimeDefinitions.TEN_MILLISECONDS, 1000, zero_short);
        
        System.out.println("Streaming OK: " + streaming_ok);
	
        /* From here on, we can get data whenever we want...*/
        
        int block_no = 0;
        
        dataFileWriter = new DataFileWriter("C:\\Output\\", 
                DataFileWriter.STREAMING, DataFileWriter.FILE_EXTENSION_TXT);
        
        try 
        {
            dataFileWriter.writeHeaderToFile(unitModel, scaleToMv);
        }
        catch(IOException ioe)
        {
            System.err.println("Error writing header to file " + dataFileWriter.getPathString());
        }
        
        timesAndValues = new TimesAndValues(PS2000Data.BUFFER_SIZE);

        //String console_input = consoleScanner.nextLine();

        //System.out.println("Input length: " + console_input.length());

        //Console system_console = System.console();

        //boolean continue_streaming = true;
//        String console_input = "";
//
//        try
//        {
//            console_input = system_console.readLine();
//        }
//        catch(NullPointerException npe)
//        {
//            continue_streaming = true;
//        }
        
        // Thread to monitor console input
        Thread console_reader_thread = new Thread(new ConsoleReader(this));
        
        console_reader_thread.start();
        
        // Execute at least once

        do
        {

            int number_of_values = ps2000JniWrapAccessor.ps2000GetValues(unitModel.getHandle(), 
                    timesAndValues, PS2000Data.BUFFER_SIZE);

            unitModel.getChannelSettings()[PS2000Data.EnPS2000Channel.PS2000_CHANNEL_A.ordinal()].setValues(timesAndValues.getBufferA());

            unitModel.getChannelSettings()[PS2000Data.EnPS2000Channel.PS2000_CHANNEL_B.ordinal()].setValues(timesAndValues.getBufferB());

            System.out.println(number_of_values + " values");
            System.out.println();

            block_no = block_no + 1;

            if(block_no > 20)
            {
                block_no = 0;

                System.out.println("Press any key and ENTER to stop.");
            }

            // Print out first 25 readings
            //printDataValues(number_of_values);

            for(int i = 0; i < number_of_values; i = i + 1)
            {
                StringBuilder data_line = new StringBuilder();

                for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
                {
                    if(unitModel.getChannelSettings()[ch].isEnabled() == true)
                    {
                        int voltage_range = PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()];

                        int data_value = AdcMvConverter.adc_to_mv(unitModel.getChannelSettings()[ch].getValues()[i], 
                                voltage_range, scaleToMv);

                        data_line.append(Integer.toString(data_value));
                        data_line.append("\t");
                    }
                }

                try
                {
                    dataFileWriter.writeDataToFile(data_line.toString());
                    dataFileWriter.writeNewLineToFile();

//                        console_input = system_console.readLine();
//                    
//                        if(console_input.isEmpty() == false)
//                        {
//                            continue_streaming = false;
//                        }
                }
                catch(IOException ioe)
                {
                    ioe.printStackTrace();
                }
            }

            /* Wait 100ms before asking again */
            try
            {
                Thread.sleep(100);  
            }
            catch (InterruptedException ie_ex) 
            {
                System.err.println("Interruption in sleep.");
            }

        }
        while(isContinueStreaming() == true);
            //console_input = consoleScanner.next();

        try
        {
            dataFileWriter.closeFile();
        }
        catch(IOException ioe)
        {
            System.err.println("Unable to close file: " + dataFileWriter.getPathString());
        }

        ps2000JniWrapAccessor.ps2000Stop(unitModel.getHandle());

        System.out.println("Collection of streaming data completed.");
        System.out.println();
        //        + "please press ENTER to return to the Main Menu.");

        //getAnyKeyInput();
    }
    
    /**
     * Collect_block_triggered
     * this function demonstrates how to collect a single block of data from the
     * unit, when a trigger event occurs.
     */
    public void collectBlockTriggered()
    {
        int threshold_mv = 500;
          
        System.out.println("Collect block on trigger...");
        System.out.println("Collects when value rises past " + threshold_mv + "mV");
        System.out.println("Press ENTER to start...");
        
        getAnyKeyInput();
        
        setDefaults();
        
        /* Trigger enabled
	 * ChannelA - to trigger unsing this channel it needs to be enabled using ps2000_set_channel
         * Rising edge
         * Threshold = 500mV
         * 10% pre-trigger  (negative is pre-, positive is post-)
         */
        
        // Object to hold simple trigger information.
        SimpleTrigger simple_trigger = new SimpleTrigger(PS2000Data.EnPS2000Channel.PS2000_CHANNEL_A, 
                (float) threshold_mv, (short) PS2000Data.En2000TriggerDirection.PS2000_RISING.ordinal(),  -10);
        
        unitModel.getTriggerChannel().setSimpleTrigger(simple_trigger);
        
        short auto_trigger_ms = 0; 
        
        short channel_value = (short) unitModel.getTriggerChannel().getSimpleTrigger().getChannel().getChannelValue();
        
        //Set the trigger values
        ps2000JniWrapAccessor.ps2000SetTrigger(unitModel.getHandle(), 
                channel_value, 
                AdcMvConverter.mv_to_adc((short) threshold_mv, PS2000Data.inputRanges[unitModel.getChannelSettings()[channel_value].getRange()]), 
                unitModel.getTriggerChannel().getSimpleTrigger().getDirection(), 
                (short) unitModel.getTriggerChannel().getSimpleTrigger().getDelay(), 
                auto_trigger_ms);
        
        /* Find the maximum number of samples, the time interval (in time_units),
         * the most suitable time units, and the maximum oversample at the current timebase
         */
        
        short block_tr_oversample = 1;
        
        TimebaseInfo timebase_info = new TimebaseInfo();
        
        while(ps2000JniWrapAccessor.ps2000GetTimebase(unitModel.getHandle(), 
                    timebase, PS2000Data.BUFFER_SIZE, block_tr_oversample, timebase_info) == 0)
        {
            timebase = (short) (timebase + 1);
        }
       
        // Start it collecting, then wait for completion
           
        TimeIndisposed time_indisposed = new TimeIndisposed();
        
        System.out.println("Calling Run Block function...");
        
        ps2000JniWrapAccessor.ps2000RunBlock(unitModel.getHandle(), 
                PS2000Data.BUFFER_SIZE, timebase, block_tr_oversample, time_indisposed);
        
        System.out.println("Waiting for trigger...");
        System.out.println("Click the Abort button to cancel");
        System.out.println();
        
//        ConsoleReader console_reader = new ConsoleReader(this);
//        Thread block_triggered_thread = new Thread(console_reader);
//        block_triggered_thread.start();
        
        setAbortButtonJFrameRunnable(new AbortButtonJFrameRunnable(this));
        
        //System.out.println(getAbortButtonJFrameRunnable().toString());
        
        SwingUtilities.invokeLater(this.getAbortButtonJFrameRunnable());
        //getAbortButtonJFrameRunnable().run();

        // Wait while the unit is not ready and a key has not been pressed.
        while((ps2000JniWrapAccessor.ps2000Ready(unitModel.getHandle()) == 0 ) && isAbortButtonPressed() == false )
        {
            try 
            {
                Thread.sleep(100);
            } 
            catch(InterruptedException ex) 
            {
                System.err.println("Interrupted thread.");
            }
        }
        
        // Once break out of the loop, stop the thread running.
        //block_triggered_thread.interrupt();
        
        if(isAbortButtonPressed() == true)
        {
            System.out.println("Data collection aborted.");
            System.out.println();
            
            // Reset button status 
            setAbortButtonPressed(false);
            
            //getConsoleScanner().next();
        }
        else
        {
            ps2000JniWrapAccessor.ps2000Stop(unitModel.getHandle());
            
            getAbortButtonJFrameRunnable().getAbortButtonJFrame().dispose();

            timesAndValues = new TimesAndValues(PS2000Data.BUFFER_SIZE); 
            
            // Get the times (in units specified by time_units) and the values (in ADC counts)
            ps2000JniWrapAccessor.ps2000GetTimesAndValues(unitModel.getHandle(), 
                timesAndValues, timebase_info.getTimeUnits(), PS2000Data.BUFFER_SIZE); 
        
            // Retrieve Channel A values
            unitModel.getChannelSettings()[PS2000Data.EnPS2000Channel.PS2000_CHANNEL_A.ordinal()].setValues(timesAndValues.getBufferA());

            unitModel.getChannelSettings()[PS2000Data.EnPS2000Channel.PS2000_CHANNEL_B.ordinal()].setValues(timesAndValues.getBufferB());
            
            // Print out the first 10 readings, converting the readings to mV if required
            System.out.println("Ten readings around trigger:");
            System.out.println();
            
            System.out.print("Time (" + AdcMvConverter.adc_units(timebase_info.getTimeUnits()) + ")\tValue (");
            
            if(scaleToMv == true)
            {
                System.out.println("mV)");
            }
            else
            {
                 System.out.println("ADC)");
            }

            // Calculation below is correct for 10% pre-trigger
            int trigger_sample = PS2000Data.BUFFER_SIZE / 10;
            
            for(int i = trigger_sample - 5; i < trigger_sample + 5; i = i + 1)
            {
                System.out.print(timesAndValues.getTimes()[i] + "\t");
                
                for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
                {
                    if(unitModel.getChannelSettings()[ch].isEnabled() == true)
                    {
                        System.out.println(AdcMvConverter.adc_to_mv(unitModel.getChannelSettings()[ch].getValues()[i], 
                                PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()], scaleToMv));
                    }
                } 
                
            }
            System.out.println();
            
            dataFileWriter = new DataFileWriter("C:\\Output\\", DataFileWriter.TRIGGERED_BLOCK, DataFileWriter.FILE_EXTENSION_TXT);

            try 
            {
                dataFileWriter.writeHeaderToFile(unitModel, scaleToMv, 
                    AdcMvConverter.adc_units(timebase_info.getTimeUnits()));

                for(int i = 0; i < timesAndValues.getTimes().length; i = i + 1)
                {
                    StringBuilder data_line = new StringBuilder();
                    data_line.append(Integer.toString(timesAndValues.getTimes()[i]));
                    data_line.append("\t");

                    for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
                    {
                        if(unitModel.getChannelSettings()[ch].isEnabled() == true)
                        {
                            int voltage_range = PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()];

                            int data_value = AdcMvConverter.adc_to_mv(unitModel.getChannelSettings()[ch].getValues()[i], 
                                    voltage_range, scaleToMv);

                            data_line.append(Integer.toString(data_value));
                            data_line.append("\t");
                        }
                    }

                    dataFileWriter.writeDataToFile(data_line.toString());
                    dataFileWriter.writeNewLineToFile();

                }

                dataFileWriter.closeFile();

            } 
            catch (IOException ioe) 
            {
                ioe.printStackTrace();
            }

            }
            
    }
    
    /**
     * Collects streaming data for the PicoScope 2203, 2204 or 2205.
     */
//    public void collectFastStreaming()
//    {
//        System.out.println("Collect streaming...");
//        
//        // Create data file
//        dataFileWriter = new DataFileWriter("C:\\Output\\", 
//                DataFileWriter.FAST_STREAMING, DataFileWriter.FILE_EXTENSION_TXT);
//        
//        System.out.println("Data is written to disk file " + dataFileWriter.getPathString());
//        System.out.println("Press ENTER key to start.");
//        
//        getAnyKeyInput();
//        
//        setDefaults();
//        
//        short zero_short = 0;
//        
//        // Trigerring cannot be used for the start of the data...
//        ps2000JniWrapAccessor.ps2000SetTrigger(unitModel.getHandle(), 
//                (short) PS2000Data.EnPS2000Channel.PS2000_NONE.ordinal(), 
//                zero_short, zero_short, zero_short, zero_short);
//        
//        AdvancedTrigger advanced_trigger = new AdvancedTrigger();
//        advanced_trigger.setAutoStop(zero_short);
//        advanced_trigger.setTotalSamples(0);
//        advanced_trigger.setTriggered(zero_short);
//        
//        unitModel.getTriggerChannel().setAdvancedTrigger(advanced_trigger);
//        
//        short streaming_ok = ps2000JniWrapAccessor.ps2000RunStreamingNS(unitModel.getHandle(), 
//                10, PS2000Data.EnPS2000TimeUnits.PS2000_US.ordinal(), 
//                PS2000Data.BUFFER_SIZE_STREAMING, (short) 1, 100, 30000);
//        
//        System.out.println("Streaming ok: " + streaming_ok);
//        
//        // From here on, we can get data whenever we want...
//        
//        
//        int n_previous_values = 0;
//        
//        timesAndValues = new TimesAndValues(PS2000Data.BUFFER_SIZE_STREAMING); 
//        
//        // Create and start thread to wait for key input
//        
//        Thread console_reader_thread = new Thread(new ConsoleReader(this));
//        console_reader_thread.start();
//                
//        while(isContinueStreaming() == true)
//        {
//            ps2000JniWrapAccessor.ps2000PollFastStreaming(unitModel.getHandle(), timesAndValues);
//            
//            if(n_previous_values != unitModel.getTriggerChannel().getAdvancedTrigger().getTotalSamples())
//            {
//                System.out.println("Values collected: " + 
//                        (unitModel.getTriggerChannel().getAdvancedTrigger().getTotalSamples() - n_previous_values));
//
//                n_previous_values = unitModel.getTriggerChannel().getAdvancedTrigger().getTotalSamples();
//            }
//
//            try
//            {
//                Thread.sleep(0);
//            }
//            catch(InterruptedException ie)
//            {
//                ie.printStackTrace();
//            }
//        }
//        
//        // Stop the unit
//        ps2000JniWrapAccessor.ps2000Stop(unitModel.getHandle());
//        
//        // Get values without aggregation
//        StreamingValuesParameters sv_parameters = new StreamingValuesParameters();
//        
//        int num_samples = ps2000JniWrapAccessor.ps2000GetStreamingValuesNoAggregation(unitModel.getHandle(), 
//                timesAndValues, sv_parameters, PS2000Data.BUFFER_SIZE_STREAMING);
//        
//        System.out.println("Completed collection of streaming data.");
//        
//        // Print out first 20 readings
//        
//        System.out.println("Printing first 20 readings:");
//        System.out.println();
//        
//        for(int i = 0; i < unitModel.getNoOfChannels(); i = i + 1)
//        {
//            if(unitModel.getChannelSettings()[i].isEnabled() == true)
//            {
//                System.out.print("Channel " + (char) ('A' + i) + " (");
//                
//                if(scaleToMv == true)
//                {
//                    System.out.print("mV) \t");
//                }
//                else
//                {
//                    System.out.print("ADC) \t");
//                }
//            }
//        }
//        
//        for(int i = 0; i < 20; i = i + 1)
//        {
//            for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
//            {
//                if(unitModel.getChannelSettings()[ch].isEnabled() == true)
//                {
//                    if(ch == PS2000Data.EnPS2000Channel.PS2000_CHANNEL_A.ordinal())
//                    {
//                        System.out.print(AdcMvConverter.adc_to_mv(timesAndValues.getBufferA()[i], PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()], scaleToMv) + "\t");
//                    }
//                    
//                    if(ch == PS2000Data.EnPS2000Channel.PS2000_CHANNEL_B.ordinal())
//                    {
//                        System.out.print(AdcMvConverter.adc_to_mv(timesAndValues.getBufferB()[i], PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()], scaleToMv));
//                    }
//                }
//            }
//            
//            System.out.println();
//        }
//        
//        // Write data to file
//        
//        try 
//        {
//            dataFileWriter.writeHeaderToFile(unitModel, scaleToMv);
//        }
//        catch(IOException ioe)
//        {
//            System.err.println("Error writing header to file " + dataFileWriter.getPathString());
//        }
//        
//        
//        for(int i = 0; i < num_samples; i = i + 1)
//        {
//            StringBuilder data_line = new StringBuilder();
//
//            for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
//            {
//                if(unitModel.getChannelSettings()[ch].isEnabled() == true)
//                {
//                    int voltage_range = PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()];
//
//                    int data_value = AdcMvConverter.adc_to_mv(unitModel.getChannelSettings()[ch].getValues()[i], 
//                            voltage_range, scaleToMv);
//
//                    data_line.append(Integer.toString(data_value));
//                    data_line.append("\t");
//                }
//            }
//
//            try
//            {
//                dataFileWriter.writeDataToFile(data_line.toString());
//                dataFileWriter.writeNewLineToFile();
//            }
//            catch(IOException ioe)
//            {
//                ioe.printStackTrace();
//            }
//        }
//        
//    }
    
    
    public void setSignalGenerator()
    {
        short sig_gen_waveform = 0;
        int sig_gen_frequency = 1000;
        short sig_gen_waveform_size = 0;
        
        // Ask user to enter signal frequency;
        System.out.println("Enter frequency in Hz: ");
        
        do
        {
            sig_gen_frequency = getConsoleScanner().nextInt();
            //getConsoleScanner().next();
        }
        while(sig_gen_frequency < 1000 || sig_gen_frequency > PS2000Data.PS2000_MAX_SIGGEN_FREQ);
        
        System.out.println("Frequency selected: " + sig_gen_frequency + " Hz");
        System.out.println();
        
        System.out.println("Signal generator On");
	System.out.println("Enter type of waveform (0..4 or 99)\n");
	System.out.println("0:\tSINE");
	System.out.println("1:\tSQUARE");
	System.out.println("2:\tTRIANGLE");
	System.out.println("3:\tRAMP UP");
	System.out.println("4:\tRAMP DOWN");
        System.out.println();
        
        do
        {
            sig_gen_waveform = getConsoleScanner().nextShort();
            //getConsoleScanner().next();
        }
        while(sig_gen_waveform < 0 || sig_gen_waveform >= PS2000Data.EnPS2000WaveType.PS2000_DC_VOLTAGE.ordinal());
        
        System.out.print("Waveform selected: ");     
        
        switch(sig_gen_waveform)
        {
            case 0:
            {
                System.out.println("Sine Wave");
                break;
            }
            case 1:
            {
                System.out.println("Square Wave");
                break;
            }
            case 2:
            {
                System.out.println("Triangle Wave");
                break;
            }
            case 3:
            {
                System.out.println("Ramp Up Wave");
                break;
            }
            case 4:
            {
                System.out.println("Ramp Down Wave");
                break;
            }
            case 99:
            {
                System.out.println("DC Voltage");
                break;
            }
            default:
                System.out.println("Invalid waveform selected.");
                        
        }
             
        System.out.println();
        
        ps2000JniWrapAccessor.ps2000SetSigGenBuiltIn(unitModel.getHandle(), 0, 
                VoltageDefinitions.ONE_VOLT_MICROVOLTS, sig_gen_waveform, 
                (float) sig_gen_frequency, (float) sig_gen_frequency, (float) 0, 
                (float) 0, 
                (short) PS2000Data.EnPS2000SweepType.PS2000_UPDOWN.ordinal(), 0);

    }
    
    
    ////////////////////////////////////////////////////////////////////////////
    //
    // Other methods
    //
    ////////////////////////////////////////////////////////////////////////////
    
    /**
     * Use where User is expected to press any key - User will need to press enter
     * to send input.
     */
    public void getAnyKeyInput()
    {
        String key_input = getConsoleScanner().nextLine();
        key_input = getConsoleScanner().nextLine();
    }
    
    public void printTimeAndDataValues(int num_values, TimebaseInfo timebase_info)
    {
        System.out.print("Time (" + AdcMvConverter.adc_units(timebase_info.getTimeUnits()) + ")\t");
        
        for(int i = 0; i < unitModel.getNoOfChannels(); i = i + 1)
        {
            if(unitModel.getChannelSettings()[i].isEnabled() == true)
            {
                System.out.print("Channel " + (char) ('A' + i) + " (");
                
                if(scaleToMv == true)
                {
                    System.out.print("mV) \t");
                }
                else
                {
                    System.out.print("ADC) \t");
                }
            }
        }
        
        System.out.println();
        
        for(int i = 0; i < num_values; i = i + 1)
        {
            System.out.print(timesAndValues.getTimes()[i] + "\t");
            
            //System.out.format("%d \t", timesAndValues.getTimes()[i]);
            
            for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
            {
                if(unitModel.getChannelSettings()[ch].isEnabled() == true)
                {
                    int voltage_range = PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()];
                    
                    System.out.print(AdcMvConverter.adc_to_mv(unitModel.getChannelSettings()[ch].getValues()[i], 
                            voltage_range, scaleToMv) + "\t");
                }
                
            }
            
            System.out.println();
            
        }
        
        System.out.println();
    }
    
    public void printDataValues(int num_values)
    {
        for(int i = 0; i < unitModel.getNoOfChannels(); i = i + 1)
        {
            if(unitModel.getChannelSettings()[i].isEnabled() == true)
            {
                System.out.print("Channel " + (char) ('A' + i) + " (");
                
                if(scaleToMv == true)
                {
                    System.out.print("mV) \t");
                }
                else
                {
                    System.out.print("ADC) \t");
                }
            }
        }
        
        System.out.println();
        
        for(int i = 0; i < num_values; i = i + 1)
        {
            
            for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
            {
                if(unitModel.getChannelSettings()[ch].isEnabled() == true)
                {
                    int voltage_range = PS2000Data.inputRanges[unitModel.getChannelSettings()[ch].getRange()];
                    
                    System.out.print(AdcMvConverter.adc_to_mv(unitModel.getChannelSettings()[ch].getValues()[i], 
                            voltage_range, scaleToMv) + "\t");
                }   
            }
            
            System.out.println();
            
        }
        
        System.out.println();
    }
    
    /**
     * Checks to see if any of the Channels on the device are enabled.
     * 
     * @return true if a channel is enabled, false otherwise.
     */
    public boolean isAChannelEnabled()
    {
        boolean is_a_channel_enabled = false;
        
        for(int ch = 0; ch < unitModel.getNoOfChannels(); ch = ch + 1)
        {
            is_a_channel_enabled = unitModel.getChannelSettings()[ch].isEnabled();
                    
            if(is_a_channel_enabled == true)
            {
                break;
            }
        }
        
        if(is_a_channel_enabled == false)
        {
            System.out.println("No Channels enabled - please choose option V.");
            System.out.println();
        }
        
        return is_a_channel_enabled;
    }
    
    
    /**
     * 
     * @param args 
     */
    public static void main(String[] args)
    {
        System.out.println("=================================================");
        System.out.println("=                                               =");
        System.out.println("= Copyright (C) 2013 Pico Technology            =");
        System.out.println("=                                               =");
        System.out.println("= PicoScope 2000 Series Java Example Program    =");
        System.out.println("=                                               =");
        System.out.println("= Version 1.0 (unsupported)                     =");
        System.out.println("=                                               =");
        System.out.println("=================================================");
        
        System.out.println();
        
        PS2000 ps2000 = new PS2000();
                
        short ps2000_handle = ps2000.getUnitModel().getHandle();
        
        PS2000Data.EnPS2000ModelType model_type = ps2000.getUnitModel().getModelType();
        
        //System.out.println("Model Type: " + model_type.toString());
        
        char ch_input = ' ';
        
        
        while ( ch_input != 'X' )
        {
            System.out.println("Please select one of the options below:");
            System.out.println();
            
            /*
           		          
            		          
            System.out.println( "Y - advanced triggered block    
            System.out.println( "E - ETS block\n" );
            
            System.out.println( "F - Fast streaming\n");
            System.out.println( "D - Fast streaming triggered\n");
            System.out.println( "G - Signal generator\n");
            System.out.println( "H - Arbitrary signal generator\n");
             * 
             */
            System.out.println("A - ADC counts/mV");
            System.out.println("V - Set voltages");
            System.out.println("I - Set timebase");
            
            if( ( model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2104)) || 
                    (model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2105)) )
            {
                if(ps2000.isPS21xxLightOn == false)
                {
                    System.out.println("L - Switch PS21XX Light On");
                }
                else
                {
                    System.out.println("L - Switch PS21XX Light Off");
                }
            }

            System.out.println("B - Immediate block");
            System.out.println("T - Triggered block");
            
            if( model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2104) || 
                        (model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2105)) ||
                        (model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2202)))
            {
                System.out.println("S - Streaming");
            }
            
            
            //Provide option for signal generation.
            if(model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2203) || 
                    model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2204) || 
                        model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2205))
            {
                System.out.println("G - Signal generator");
            }
            
            
            System.out.println("X - Exit");
            System.out.println();
            System.out.println("Operation:");
            
            // try 
            // {
            // ch_input = (char) System.in.read();
            String input_string = ps2000.getConsoleScanner().next();

            if(input_string.length() > 0)
            {
                ch_input = input_string.charAt(0);
                ch_input = Character.toUpperCase(ch_input);
            }
          
//            } 
//            catch (IOException ex) 
//            {
//                System.out.println("Error reading in user selection - "
//                        + "exiting application");
//                
//                Logger.getLogger(PS2000.class.getName()).log(Level.SEVERE, null,
//                        ex);
//                
//                System.exit(1);
//            }
            
            System.out.println("Option selected: " + ch_input);
            System.out.println();
            
            switch(ch_input)
            {
                case 'A':
                {
                    if(ps2000.isScaleToMv() == true)
                    {
                        System.out.println("Readings will be scaled in ADC counts.");
                        
                        ps2000.setScaleToMv(false);
                    }
                    else
                    {
                        System.out.println("Readings will be scaled in mV.");
                        
                        ps2000.setScaleToMv(true);
                    }
                    
                    System.out.println();

                    break;
                }
                case 'B':
                {
                    if(ps2000.isAChannelEnabled() == true)
                    {
                        ps2000.collectBlockImmediate();
                    }
                    break;
                }
                case 'G':
                {
                    if(model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2203) || 
                            model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2204) || 
                            model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2205))
                    {
                        ps2000.setSignalGenerator();
                    }
                    else
                    {
                        System.out.println("This option is not supported by "
                                + "this model - please try again.");
                    }
                    
                    break;
                }
                case 'I':
                {
                    ps2000.setTimebase();
                    break;
                }   
                case 'L':
                {
                    if(( model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2104)) || 
                    (model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2105)))
                    {
                        if(ps2000.isPS21xxLightOn() == false)
                        {
                            ps2000.setPS21xxLight(ps2000_handle, true);
                        }
                        else
                        {
                            ps2000.setPS21xxLight(ps2000_handle, false);
                        }
                    }
                    else
                    {
                        System.out.println("This option is not supported by "
                                + "this model - please try again.");
                    }                        
                    break;
                }
                case 'S':
                {
                    if(ps2000.isAChannelEnabled() == false)
                    {
                        break;
                    }
                    
                    if( model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2104) || 
                        (model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2105)) ||
                        (model_type.equals(PS2000Data.EnPS2000ModelType.MODEL_PS2202)))
                    {
                        ps2000.collectStreaming();  
                    }
                    else
                    {
                        System.out.println("Invalid option - this model does not support this type of streaming.");
                    }
                    
                    break;
                }
                case 'T':
                {
                    if(ps2000.isAChannelEnabled() == true)
                    {
                        ps2000.collectBlockTriggered();
                    }
                    break;
                }
                case 'V':
                {
                    ps2000.setVoltages();
                    break;
                }    
                case 'X':
                {
                    System.out.println("Exiting application...");
                    break;
                }
                default:
                {
                    System.out.println("Invalid option selected - please "
                            + "try again.");
                    
                    break;
                }
                    
            }
            
         
        }
        
        // Close unit
        
        short close_status = ps2000.getPs2000JniWrapAccessor().ps2000CloseUnit(
                ps2000.unitModel.getHandle());
        
        System.out.println("Exit status: " + close_status);
        
        System.exit(0);
        
    }
}
