/**************************************************************************
 *
 * Filename:    PS2000Data.java
 *
 * Copyright:   Pico Technology Limited 2011
 *
 * Author:      HSM
 *
 * Description:
 *   This class stores pre-defined data values for the PicoScope 2000 series.
 *	
 *
 * History:
 *     27Jul11 HSM Created
 *
 * Revision Info: "file %n date %f revision %v"
 *						""
 *
 ***************************************************************************/

package com.picotech.picoscope.ps2000;

/**
 *
 * @author hitesh
 */
public class PS2000Data 
{
    //Defined values
    /** */
    public static final short BUFFER_SIZE               = 1024;
    /**  */
    public static final int   BUFFER_SIZE_STREAMING     = 100000;
    
    /** */
    public static final short MAX_CHANNELS              = 4;
    
    /** */
    public static final short PS2000_FIRST_USB          = 1;
    
    /** */
    public static final short PS2000_LAST_USB           = 127;
    
    /** */
    public static final short PS2000_MAX_UNITS          = (PS2000_LAST_USB - 
            PS2000_FIRST_USB + 1);
    
    /** */
    public static final short PS2000_MAX_VALUE          = 32767;
    /** */
    public static final short PS2000_MIN_VALUE          = -32767;
    /** */
    public static final short PS2000_LOST_DATA          = -32768;
    
    /** */
    public static final short PS2000_MAX_TIMEBASE       = 19;
    /** */
    public static final short PS2105_MAX_TIMEBASE       = 20;
    /** */
    public static final short PS2104_MAX_TIMEBASE       = 19;
    /** */
    public static final short PS2200_MAX_TIMEBASE       = 23;
    /** */
    public static final short PS2000_MAX_OVERSAMPLE     = 256;
    
    
    public static final float PS2000_MAX_SIGGEN_FREQ    = 100000.0f;

    /**
     * Voltage input ranges
     */
    public static final int[] inputRanges = {10, 20, 50, 100, 200, 500, 1000, 
        2000, 5000, 10000, 20000, 50000};
    
    //Enumerations
    
    /**
     * 
     */
    public static enum EnPS2000Channel 
    {
        PS2000_CHANNEL_A (0),
	PS2000_CHANNEL_B (1),
	PS2000_CHANNEL_C (2),
	PS2000_CHANNEL_D (3),
	PS2000_EXTERNAL (4),
	PS2000_MAX_CHANNELS (MAX_CHANNELS),
	PS2000_NONE (5);
        
        private final int channelValue;
        
        /**
         * 
         * @param channel_value 
         */
        EnPS2000Channel(int channel_value)
        {
            channelValue = channel_value;
        }

        /**
         * 
         * @return 
         */
        public int getChannelValue() 
        {
            return channelValue;
        }
        
    }
    
    /**
     * 
     */
    public static enum EnPS2000Range
    {
	PS2000_10MV,
	PS2000_20MV,
	PS2000_50MV,
	PS2000_100MV,
	PS2000_200MV,
	PS2000_500MV,
	PS2000_1V,
	PS2000_2V,
	PS2000_5V,
	PS2000_10V,
	PS2000_20V,
        PS2000_50V,
	PS2000_MAX_RANGES;
    }	

    /**
     * 
     */
    public static enum EnPS2000TimeUnits
    {
        PS2000_FS,
        PS2000_PS,
        PS2000_NS,
        PS2000_US,
        PS2000_MS,
        PS2000_S,
        PS2000_MAX_TIME_UNITS,
    }	

    /**
     * 
     */
    public static enum EnPS2000Error
    {
        PS2000_OK,
        PS2000_MAX_UNITS_OPENED,	// more than PS2000_MAX_UNITS
        PS2000_MEM_FAIL,		//not enough RAM on host machine
        PS2000_NOT_FOUND,		//cannot find device
        PS2000_FW_FAIL,			//unabled to download firmware 
        PS2000_NOT_RESPONDING,
        PS2000_CONFIG_FAIL,		//missing or corrupted configuration settings
        PS2000_OS_NOT_SUPPORTED,	//need to use win98SE (or later) or win2k (or later)
        PS2000_PICOPP_TOO_OLD,
    }	
    
    /**
     * 
     */
    public static enum EnPS2000OpenProgress
    {
        PS2000_OPEN_PROGRESS_FAIL (-1),
        PS2000_OPEN_PROGRESS_PENDING (0),
        PS2000_OPEN_PROGRESS_COMPLETE (1);
        
        private final int openProgress;
        
        EnPS2000OpenProgress(int open_progress)
        {
            openProgress = open_progress;
        }
        
        public short getOpenProgress()
        {
            return (short) openProgress;
        }
        
    }
    
    /**
     * 
     */
    public static enum EnPS2000ModelType
    {
	MODEL_NONE (0),
        MODEL_PS2104 (2104),
	MODEL_PS2105 (2105),
	MODEL_PS2202 (2202),
	MODEL_PS2203 (2203),
	MODEL_PS2204 (2204),
	MODEL_PS2205 (2205);
        
        private final int PS2000ModelType;
        
        /**
         * 
         * @param ps2000_model_type 
         */
        EnPS2000ModelType(int ps2000_model_type)
        {
            PS2000ModelType = ps2000_model_type;
        }

        /**
         * 
         * @return 
         */
        public int getPS2000ModelType() 
        {
            return PS2000ModelType;
        }

    }
    
    public static enum EnPS2000Info
    {
        PS2000_DRIVER_VERSION,
	PS2000_USB_VERSION,
	PS2000_HARDWARE_VERSION,
	PS2000_VARIANT_INFO,
	PS2000_BATCH_AND_SERIAL,
	PS2000_CAL_DATE,
	PS2000_ERROR_CODE,
        PS2000_KERNEL_DRIVER_VERSION
    }
    
    public static enum EnPS2000EtsMode 
    {
        PS2000_ETS_OFF,         // ETS disabled
        PS2000_ETS_FAST,        // Return ready as soon as requested no of interleaves is available
        PS2000_ETS_SLOW,        // Return ready every time a new set of no_of_cycles is collected
        PS2000_ETS_MODES_MAX
    }
    
    public static enum En2000TriggerDirection
    {
        PS2000_RISING,
        PS2000_FALLING,
        PS2000_MAX_DIRS
    }
    
    public static enum EnPS2000WaveType
    {
        PS2000_SINE,
        PS2000_SQUARE,
        PS2000_TRIANGLE,
        PS2000_RAMPUP,
        PS2000_RAMPDOWN,
        PS2000_DC_VOLTAGE
    }
    
    public static enum EnPS2000SweepType
    {
        PS2000_UP,
        PS2000_DOWN,
        PS2000_UPDOWN,
        PS2000_DOWNUP,
        MAX_SWEEP_TYPES
    }
    
    public static enum EnPS2000TriggerState
    {
        PS2000_CONDITION_DONT_CARE,
        PS2000_CONDITION_TRUE,
        PS2000_CONDITION_FALSE,
	PS2000_CONDITION_MAX
    }
    
    public static enum EnPS2000PulseWidthType
    {
        PS2000_PW_TYPE_NONE,
        PS2000_PW_TYPE_LESS_THAN,
	PS2000_PW_TYPE_GREATER_THAN,
	PS2000_PW_TYPE_IN_RANGE,
	PS2000_PW_TYPE_OUT_OF_RANGE
    }
    
}