/**************************************************************************
 *
 * Filename:    PS2000JNIWrapAccessor.java
 *
 * Copyright:   Pico Technology Limited 2011
 *
 * Author:      HSM
 *
 * Description:
 *   This class provides access to the PS2000 JNI Wrapper Accessor.
 *
 * History:
 *     27Jul11 HSM Created
 *
 * Revision Info: "file %n date %f revision %v"
 *						""
 *
 ***************************************************************************/
package com.picotech.picoscope.ps2000;

//import com.picotech.picoscope.StreamingValuesParameters;
import com.picotech.picoscope.TimeIndisposed;
import com.picotech.picoscope.TimebaseInfo;
import com.picotech.picoscope.TimesAndValues;

/**
 *
 * @author hitesh
 */
public class PS2000JNIWrapAccessor 
{

    /**
     * Calls the function ps2000_open_unit
     * 
     * @return -1: if the oscilloscope fails to open.
                0: if no oscilloscope is found.
                >0 (oscilloscope handle): if the oscilloscope opened. Use this as the
                handle argument for all subsequent API calls for this oscilloscope.
     */
    public native short ps2000OpenUnit();
    
    /**
     * 
     * @param handle the handle of the required oscilloscope.
     * 
     * @return 
     */
    public native short ps2000CloseUnit(short handle);
    
    /**
     * 
     * @param handle
     * @param line_code
     * @return 
     */
    public native String ps2000GetInfo(short handle, short line_code); 
        
    /**
     * Calls the dll function ps2000_get_streaming_values_no_aggregation.
     * 
     * This function retrieves raw streaming data from the driver's data store after fast 
     * streaming has stopped.
     * 
     * <b>NOTE:</b> Only to be used with the PicoScope 2203, 2204 and 2205.
     * Not compatible with ETS triggering - has no effect in ETS mode.
     * 
     * @param handle the handle of the required oscilloscope.
     * @param times_and_values object to store data values
     * @param sv_parameters streaming parameters required
     * @param no_of_values the number of values required.
     * 
     * @return The number of values written to each buffer, if successful.
     *          0: if a parameter was out of range.
     */
//    public native int ps2000GetStreamingValuesNoAggregation(short handle, 
//            TimesAndValues times_and_values, StreamingValuesParameters sv_parameters, 
//            int no_of_values);
            
    
    /**
     * This method is used to call the ps2000_get_timebase
     * 
     * @param handle the handle of the required oscilloscope.
     * @param timebase a code between 0 and the maximum timebase (depending on the oscilloscope).
     * @param numSamples the number of samples that are required.
     * @param oversample the amount of oversample required.
     * @param timebase_info object containing time interval, time units and max samples variables
     * @return non-zero: if all parameters are in range. 0: on error.
     */
    public native short ps2000GetTimebase(short handle, short timebase, int numSamples, short oversample, TimebaseInfo timebase_info);
    
    /**
     * This method is used to call the ps2000_get_times_and_values function via the dll.
     * 
     * @param handle
     * @param timesAndValues
     * @param time_units
     * @param no_of_values
     * @return 
     */
    public native int ps2000GetTimesAndValues(short handle, TimesAndValues timesAndValues, short time_units, int no_of_values);
    
    
    /**
     * This method calls the ps2000_get_values dll function to get values
     * 
     * @param handle the handle of the required oscilloscope.
     * @param timesAndValues - object containing buffers and variables to pass to the wrapper dll.
     * @param no_of_values - the number of data points to return. In streaming mode, this is the maximum number of values to return.
     * @return The number of data values per channel returned.
     */
    public native int ps2000GetValues(short handle, TimesAndValues timesAndValues, int no_of_values);
    
    /**
     * Calls the dll function ps2000_get_streaming_last_values. The wrapper dll function
     * makes use of a callback function to capture the data.
     * 
     * @param handle the handle of the required oscilloscope
     * @param Object to hold data values
     * @return 
     *  1: if the callback will be called.
        0: if the callback will not be called, either because one of the inputs
        is out of range or because there are no samples available.
     */
    //public native short ps2000PollFastStreaming(short handle, TimesAndValues times_and_values);
    
    
    /**
     * This method calls the dll function to see if the oscilloscope has 
     * finished the last data collection operation.
     * 
     * @param handle the handle of the required oscilloscope.
     * @return >0: if ready. -1: if the oscilloscope is not attached.
     */
    public native short ps2000Ready(short handle);
    
    /**
     * This method calls the dll function to collect a block of data.
     * 
     * @param handle the oscilloscope of the required oscilloscope.
     * @param no_of_samples the number of samples to return.
     * @param timebase a code between 0 and the maximum timebase available
     * @param oversample the oversampling factor, a number between 1 and 256.
     * @param time_indisposed_ms a pointer to the approximate time, in
                milliseconds, that the ADC will take to collect data.
     * @return 0: if one of the parameters is out of range.
                non-zero: if successful.
     */
    public native short ps2000RunBlock(short handle, int no_of_samples, short timebase, short oversample, TimeIndisposed time_indisposed_ms);
    
    /**
     * This function tells the oscilloscope to start collecting data in fast streaming mode. It
       returns immediately without waiting for data to be captured. After calling it, you
       should next call ps2000_get_streaming_last_values() to copy the data to your
       application's buffer.
     * 
     * <b>NOTE:</b> PicoScope 2203, 2204 and 2205 only.  
     * 
     * @param handle the handle of the required oscilloscope.
     * @param sample_interval the time interval, in time_units, between data points.
     * @param time_units the units in which sample_interval is measured.
     * @param max_samples the maximum number of samples that the driver should store from each channel.
     * @param auto_stop a Boolean to indicate whether streaming should stop automatically when max_samples is reached. Set to any non-zero value for TRUE.
     * @param noOfSamplesPerAggregate the number of incoming samples that the driver will merge together.
     * @param overview_buffer_size the size of the overview buffers
     * @return non-zero: if streaming has been enabled correctly. 0: if a problem occurred or a value was out of range.
     */
    public native short ps2000RunStreamingNS(short handle, int sample_interval, int time_units, int max_samples, short auto_stop, int noOfSamplesPerAggregate, int overview_buffer_size);
    
    /**
     * This method calls the dll function to start collecting data in compatible streaming mode.
     * 
     * @param handle the handle of the required oscilloscope.
     * @param sample_interval_ms the time interval, in milliseconds, between
        data points. This can be no shorter than 1 ms.
     * @param max_samples the maximum number of samples that the driver is
        to store. This can be no greater than 60 000.
     * @param windowed if this is 0, only the values taken since the last call to
        ps2000_get_values() are returned. If this is 1, the number of
        values requested by ps2000_get_values() are returned, even if they
        have already been read by ps2000_get_values().
     * @return non-zero: if streaming has been enabled correctly. 0: if a problem occurred or a value was out of range.
     */
    public native short ps2000RunStreaming(short handle, short sample_interval_ms, int max_samples, short windowed);
    
    /**
     * This method calls the native ps2000_set_light() function to switch on 
     * the probe tip light on the PicoScope 2104 and 2105 ONLY.
     * 
     * @param handle
     * @param state
     * 
     * @return 
     */
    public native short ps2000SetLight(short handle, short state);
    
    /**
     * 
     * @param handle
     * @param channel
     * @param enabled
     * @param dc
     * @param range
     * 
     * @return 
     */
    public native short ps2000SetChannel(short handle, short channel, short enabled, short dc, short range);
    
    /**
     * 
     * @param handle
     * @param mode
     * @param ets_cycles
     * @param ets_interleave
     * 
     * @return 
     */
    public native int ps2000SetETS(short handle, short mode, short ets_cycles,
            short ets_interleave);
    
    
    /**
     * This function sets up the signal generator to produce a signal from a list of built-in
        waveforms. If different start and stop frequencies are specified, the oscilloscope will
        sweep either up, down or up and down.
     * 
     * @param handle the handle of the required oscilloscope
     * @param offsetVoltage the voltage offset, in microvolts, to be applied to the waveform
     * @param pkToPk
     * @param waveType
     * @param startFrequency
     * @param stopFrequency
     * @param increment
     * @param dwellTime
     * @param sweepType
     * @param sweeps
     * @return 
     */
    public native short ps2000SetSigGenBuiltIn(short handle, int offsetVoltage, int pkToPk, short waveType, 
            float startFrequency, float stopFrequency, float increment, float dwellTime, short sweepType,
            int sweeps);
    
    /**
     * This method calls the dll function used to enable or disable basic triggering and its parameters.
     * 
     * @param handle the handle of the required oscilloscope.
     * @param source where to look for a trigger.
     * @param threshold the threshold for the trigger event.
     * @param direction use PS2000_RISING (0) or PS2000_FALLING (1)
     * @param delay the delay, as a percentage of the requested number of data
                points, between the trigger event and the start of the block.
     * @param auto_trigger_ms the delay in milliseconds after which the
                oscilloscope will collect samples if no trigger event occurs.
     * 
     * @return 0: if one of the parameters is out of range.
     *      non-zero: if successful.
     */
    public native short ps2000SetTrigger(short handle, short source, 
            short threshold, short direction, short delay, short auto_trigger_ms);
    
    
    
    /**
     * This method calls the dll function to stop the oscilloscope sampling data. If this function is called
     * before a trigger event occurs, the oscilloscope may not contain valid data.
     * 
     * @param handle the handle of the required oscilloscope.
     * @return 0: if an invalid handle is passed. non-zero: if successful.
     */
    public native short ps2000Stop(short handle);
    
    
    static
    {
        System.loadLibrary("PS2000JNIWrap");
    }
    
    
    public PS2000JNIWrapAccessor() 
    {
        
    }
    
    
    
    
}
