/**************************************************************************
 *
 * Filename:    UnitModel.java
 *
 * Copyright:   Pico Technology Limited 2011
 *
 * Author:      HSM
 *
 * Description:
 *   Class to hold information on a unit.
 *
 * History:
 *     27Jul11 HSM Created
 *
 * Revision Info: "file %n date %f revision %v"
 *						""
 *
 ***************************************************************************/
package com.picotech.picoscope.ps2000;

import com.picotech.picoscope.TriggerChannel;
import com.picotech.picoscope.ChannelSettings;
import com.picotech.picoscope.UnitInfo;
import com.picotech.picoscope.ps2000.PS2000Data.EnPS2000ModelType;
import com.picotech.picoscope.ps2000.PS2000Data.EnPS2000Range;

/**
 * This class holds information on a PicoScope Unit
 * 
 * @author hitesh
 */
public class UnitModel 
{
    ////////////////////
    //
    // Variables
    //
    ////////////////////
    
    private short handle;
    
    private PS2000Data.EnPS2000ModelType modelType;
    private PS2000Data.EnPS2000Range firstRange;
    private PS2000Data.EnPS2000Range lastRange;
    
    private TriggerChannel triggerChannel;
    
    private short maxTimebase;
    private short timebases;
    private short noOfChannels;
    
    private ChannelSettings[] channelSettings;
    
    private boolean hasFastStreaming;
    private boolean hasEts;
    private boolean hasSignalGenerator;

    private boolean hasAdvancedTriggering;
    
    private UnitInfo unitInfo;
    
    ////////////////////
    //
    // Constructor
    //
    ////////////////////
    
    /**
     * Constructor - creates new object to hold information on the Unit
     * 
     * @param handle 
     */
    public UnitModel(short unit_handle) 
    {
        handle = unit_handle;
        
        triggerChannel = new TriggerChannel();
    }
    
    /**
     * Constructor - creates new object to hold information on the Unit
     * 
     * @param handle 
     */
    public UnitModel() 
    {
       triggerChannel = new TriggerChannel(); 
    }
    
    
    ///////////////////////
    //
    // Getter and Setters
    //
    ///////////////////////
    public short getHandle() 
    {
        return handle;
    }

    public void setHandle(short unit_handle) 
    {
        handle = unit_handle;
    }

    public EnPS2000Range getFirstRange() 
    {
        return firstRange;
    }

    public void setFirstRange(EnPS2000Range first_range) 
    {
        firstRange = first_range;
    }

    public EnPS2000Range getLastRange() 
    {
        return lastRange;
    }

    public void setLastRange(EnPS2000Range last_range) 
    {
        lastRange = last_range;
    }

    public EnPS2000ModelType getModelType() 
    {
        return modelType;
    }

    public void setModelType(EnPS2000ModelType model_type) 
    {
        modelType = model_type;
    }

    public TriggerChannel getTriggerChannel() 
    {
        return triggerChannel;
    }

    public void setTriggerChannel(TriggerChannel trigger_channel) 
    {
        triggerChannel = trigger_channel;
    }
    
    

    public boolean getHasAdvancedTriggering() 
    {
        return hasAdvancedTriggering;
    }

    public void setHasAdvancedTriggering(boolean has_advanced_triggering) 
    {
        hasAdvancedTriggering = has_advanced_triggering;
    }

    public boolean getHasEts() 
    {
        return hasEts;
    }

    public void setHasEts(boolean has_ets) 
    {
        hasEts = has_ets;
    }

    public boolean getHasFastStreaming() 
    {
        return hasFastStreaming;
    }

    public void setHasFastStreaming(boolean has_fast_streaming) 
    {
        hasFastStreaming = has_fast_streaming;
    }

    public boolean getHasSignalGenerator() 
    {
        return hasSignalGenerator;
    }

    public void setHasSignalGenerator(boolean has_signal_generator) 
    {
        hasSignalGenerator = has_signal_generator;
    }

    public short getMaxTimebase() 
    {
        return maxTimebase;
    }

    public void setMaxTimebase(short max_timebase) 
    {
        maxTimebase = max_timebase;
    }

    public short getNoOfChannels() 
    {
        return noOfChannels;
    }

    public void setNoOfChannels(short no_of_channels) 
    {
        this.noOfChannels = no_of_channels;
    }

    public short getTimebases() 
    {
        return timebases;
    }

    public void setTimebases(short unit_timebases) 
    {
        timebases = unit_timebases;
    }

    public ChannelSettings[] getChannelSettings() 
    {
        return channelSettings;
    }

    public void setChannelSettings(ChannelSettings[] channel_settings) 
    {
        channelSettings = channel_settings;
    }

    public UnitInfo getUnitInfo() 
    {
        return unitInfo;
    }

    public void setUnitInfo(UnitInfo unit_info) 
    {
        unitInfo = unit_info;
    }
      
}

