#include <windows.h>
#include <stdio.h>
#include <jni.h>
#include "ps2000.h"

#define TRUE 1
#define FALSE 0

// User defined variable
short isDebugModeOn = FALSE;

// Variables to return values

jshort jsHandle;			// Store the current handle value
jshort jsStatus;			// Store the current PICO_STATUS value


// variables for callback function
//short _ready = 0;
//short *_buffers[] = {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL};
//unsigned long _bufferSizes[] = {0, 0, 0, 0, 0, 0, 0, 0};
//short _overflow;
//unsigned long _triggeredAt;
//short _triggered;
//short _auto_stop;
//unsigned long _nValues;


// Callback function
//void __stdcall GetValuesCallback(short **overviewBuffers, short overflow, unsigned long triggeredAt, short triggered,
//  short auto_stop, unsigned long nValues)
//{    
//  if(_ready == 0)
//  {
//    int co = 0;
//	unsigned long bufferSize = 0;
//
//    for(co = 0; co < 8; co++)
//    {      
//      if(overviewBuffers[co] != NULL && _buffers[co] != NULL)
//      {
//
//        if(nValues > _bufferSizes[co])
//		{
//			bufferSize = _bufferSizes[co];
//		}
//		else
//		{
//			bufferSize = nValues;
//		}
//
//        memcpy(_buffers[co], overviewBuffers[co], bufferSize * sizeof(short));
//      }
//    }
//
//	  _overflow = overflow;
//	  _triggeredAt = triggeredAt;
//	  _triggered = triggered;
//	  _auto_stop = auto_stop;
//	  _nValues = nValues;
//	  _ready = 1;
//  }
//}


void checkExceptionOccurred(JNIEnv * jni_env, const char * j_method)
{
	if((*jni_env)->ExceptionOccurred(jni_env)) 
	{
		//printf("Error occurred calling method %s", j_method);
		(*jni_env)->ExceptionDescribe(jni_env);
		(*jni_env)->ExceptionClear(jni_env);
	}
}

/**
*	Function to call ps2000_open_unit
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000OpenUnit
  (JNIEnv * env, jobject jobj)
{
	jsHandle = ps2000_open_unit();

	return jsHandle;
}

/**
*	Function to call ps2000_close_unit
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000CloseUnit
  (JNIEnv * env, jobject jobj, jshort js_handle)
{
	jsStatus = ps2000_close_unit(js_handle);

	return jsStatus;
}

/**
*	Function to call ps2000_get_unit_info
*
**/
JNIEXPORT jstring JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000GetInfo
  (JNIEnv * env, jobject jobj, jshort handle, jshort line_code)
{
	char info_line[80];
	
	ps2000_get_unit_info(handle, info_line, sizeof(info_line), line_code);

	return ((*env)->NewStringUTF(env, info_line));
}

/**
* Function to call ps2000_get_times_and_values
*
**/
//JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000GetStreamingLastValues
//  (JNIEnv *, jobject, jshort, jobject);
//{
//
//}

/**
* Function to call ps2000_get_times_and_values
*
**/
JNIEXPORT jint JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000GetTimesAndValues
  (JNIEnv * env, jobject jobj, jshort js_handle, jobject jobj_times_and_values, jshort js_time_units, jint ji_no_of_samples)
{
	// Declare variables
	jclass jc_times_and_values;

	jmethodID jmid_get_overflow;

	jmethodID jmid_set_bufferA;
	jmethodID jmid_set_bufferB;
	jmethodID jmid_set_overflow;
	jmethodID jmid_set_times;

	jint ji_data_values_per_channel;
	jshort js_overflow = 0;

	jshortArray jsa_buffer_A;
	jshortArray jsa_buffer_B;
	jintArray jia_buffer_times;

	//Arrays to store values - JNI arrays do not have a typedef equivalent

	short *buffer_ch_a;
	short *buffer_ch_b;
	long *buffer_times;

	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetTimesAndValues: using calloc...\n");
	}

	buffer_ch_a = (short*) calloc(ji_no_of_samples, sizeof(short));
	buffer_ch_b = (short*) calloc(ji_no_of_samples, sizeof(short));
	buffer_times = (long*) calloc(ji_no_of_samples, sizeof(long));

	// Get class 
	jc_times_and_values = (*env)->GetObjectClass(env, jobj_times_and_values);

	// Get method identifiers 
	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetTimesAndValues: Getting method IDs\n");
	}

	jmid_get_overflow = (*env)->GetMethodID(env, jc_times_and_values, "getOverflow", "()S");

	jmid_set_bufferA = (*env)->GetMethodID(env, jc_times_and_values, "setBufferA", "([S)V");
	jmid_set_bufferB = (*env)->GetMethodID(env, jc_times_and_values, "setBufferB", "([S)V");
	jmid_set_overflow = (*env)->GetMethodID(env, jc_times_and_values, "setOverflow", "(S)V");
	jmid_set_times = (*env)->GetMethodID(env, jc_times_and_values, "setTimes", "([I)V");

	// Check methods
	
	if(jmid_get_overflow == 0)
	{
		printf("Can't find method getOverflow.\n");
		return 0;
	}

	if(jmid_set_bufferA == 0)
	{
		printf("Can't find method setBufferA.\n");
		return 0;
	}

	if(jmid_set_bufferB == 0)
	{
		printf("Can't find method setBufferB.\n");
		return 0;
	}

	if(jmid_set_overflow == 0)
	{
		printf("Can't find method setOverflow.\n");
		return 0;
	}

	if(jmid_set_times == 0)
	{
		printf("Can't find method setTimes.\n");
		return 0;
	}

	//Call method
	(*env)->ExceptionClear(env);
	(*env)->CallShortMethod(env, jobj_times_and_values, jmid_get_overflow, js_overflow);
	checkExceptionOccurred(env, "getOverflow");

	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetTimesAndValues: Calling ps2000_get_times_and_values\n");
	}

	// Call get_times_and_values function
	ji_data_values_per_channel = ps2000_get_times_and_values(js_handle, buffer_times, buffer_ch_a, buffer_ch_b,
		NULL, NULL, &js_overflow, js_time_units, ji_no_of_samples);

	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetTimesAndValues: Creating arrays...\n");
	}

	// Create arrays
	jsa_buffer_A = (*env)->NewShortArray(env, ji_no_of_samples);
	jsa_buffer_B = (*env)->NewShortArray(env, ji_no_of_samples);

	jia_buffer_times = (*env)->NewIntArray(env, ji_no_of_samples);

	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetTimesAndValues: Setting data to arrays...\n");
	}

	// Set data for arrays
	(*env)->SetShortArrayRegion(env, jsa_buffer_A, 0, ji_no_of_samples, buffer_ch_a);
	(*env)->SetShortArrayRegion(env, jsa_buffer_B, 0, ji_no_of_samples, buffer_ch_b);
	(*env)->SetIntArrayRegion(env, jia_buffer_times, 0, ji_no_of_samples, buffer_times);

	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetTimesAndValues: Setting arrays...\n");
	}

	// Return array values
	(*env)->ExceptionClear(env);
	(*env)->CallVoidMethod(env, jobj_times_and_values, jmid_set_bufferA, jsa_buffer_A);
	checkExceptionOccurred(env, "setBufferA");
	(*env)->CallVoidMethod(env, jobj_times_and_values, jmid_set_bufferB, jsa_buffer_B);
	checkExceptionOccurred(env, "setBufferB");
	(*env)->CallVoidMethod(env, jobj_times_and_values, jmid_set_times, jia_buffer_times);
	checkExceptionOccurred(env, "setTimes");
	
	//printf("PS2000JNIWrapAccessor_ps2000GetTimesAndValues: Releasing elements...\n");

	////Release elements
	//(*env)->ReleaseShortArrayElements(env, jsa_buffer_A, buffer_ch_a, 0);
	//(*env)->ReleaseShortArrayElements(env, jsa_buffer_B, buffer_ch_b, 0);
	//(*env)->ReleaseIntArrayElements(env, jsa_buffer_A, buffer_times, 0);
	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetTimesAndValues: Freeing buffers...\n");
	}

	// Free buffers

	free(buffer_ch_a);
	free(buffer_ch_b);
	free(buffer_times);

	return ji_data_values_per_channel;
}

/**
* Function to call ps2000_get_values
*
**/
JNIEXPORT jint JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000GetValues
  (JNIEnv * env, jobject jobj, jshort js_handle, jobject jobj_times_and_values, jint ji_num_values)
{
	// Declare variables
	jclass jc_times_and_values;

	jmethodID jmid_get_overflow;

	jmethodID jmid_set_bufferA;
	jmethodID jmid_set_bufferB;
	jmethodID jmid_set_overflow;

	jint ji_data_values_per_channel;
	jshort js_overflow = 0;

	jshortArray jsa_buffer_A;
	jshortArray jsa_buffer_B;

	//Arrays to store values - JNI arrays do not have a typedef equivalent

	short *buffer_ch_a;
	short *buffer_ch_b;

	// Use calloc to allocate memory for the arrays
	buffer_ch_a = (short*) calloc(ji_num_values, sizeof(short));
	buffer_ch_b = (short*) calloc(ji_num_values, sizeof(short));
	
	// Get class 
	jc_times_and_values = (*env)->GetObjectClass(env, jobj_times_and_values);

	// Get method identifiers 
	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetValues: Getting method IDs\n");
	}

	jmid_get_overflow = (*env)->GetMethodID(env, jc_times_and_values, "getOverflow", "()S");

	jmid_set_bufferA = (*env)->GetMethodID(env, jc_times_and_values, "setBufferA", "([S)V");
	jmid_set_bufferB = (*env)->GetMethodID(env, jc_times_and_values, "setBufferB", "([S)V");
	jmid_set_overflow = (*env)->GetMethodID(env, jc_times_and_values, "setOverflow", "(S)V");

	// Check methods
	
	if(jmid_get_overflow == 0)
	{
		printf("Can't find method getOverflow.\n");
		return 0;
	}

	if(jmid_set_bufferA == 0)
	{
		printf("Can't find method setBufferA.\n");
		return 0;
	}

	if(jmid_set_bufferB == 0)
	{
		printf("Can't find method setBufferB.\n");
		return 0;
	}

	if(jmid_set_overflow == 0)
	{
		printf("Can't find method setOverflow.\n");
		return 0;
	}

	//Call method
	(*env)->ExceptionClear(env);
	(*env)->CallShortMethod(env, jobj_times_and_values, jmid_get_overflow, js_overflow);
	checkExceptionOccurred(env, "getOverflow");

	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetValues: Calling ps2000_get_times_and_values\n");
	}

	//Get values
	ji_data_values_per_channel = ps2000_get_values(js_handle, buffer_ch_a, buffer_ch_b, NULL, NULL, &js_overflow, ji_num_values);

	///////////////////////////////////////////////////
	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetValues: Creating arrays...\n");
	}

	// Create arrays
	jsa_buffer_A = (*env)->NewShortArray(env, ji_num_values);
	jsa_buffer_B = (*env)->NewShortArray(env, ji_num_values);

	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetValues: Setting data to arrays...\n");
	}

	// Set data for arrays
	(*env)->SetShortArrayRegion(env, jsa_buffer_A, 0, ji_num_values, buffer_ch_a);
	(*env)->SetShortArrayRegion(env, jsa_buffer_B, 0, ji_num_values, buffer_ch_b);


	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetValues: Setting arrays...\n");
	}

	// Return array values
	(*env)->ExceptionClear(env);
	(*env)->CallVoidMethod(env, jobj_times_and_values, jmid_set_bufferA, jsa_buffer_A);
	checkExceptionOccurred(env, "setBufferA");
	(*env)->CallVoidMethod(env, jobj_times_and_values, jmid_set_bufferB, jsa_buffer_B);
	checkExceptionOccurred(env, "setBufferB");

	if(isDebugModeOn)
	{
		printf("PS2000JNIWrapAccessor_ps2000GetTimesAndValues: Freeing buffers...\n");
	}

	// Free buffers

	free(buffer_ch_a);
	free(buffer_ch_b);



	return ji_data_values_per_channel;
}


/**
* Function to call ps2000_get_timebase
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000GetTimebase
  (JNIEnv * env, jobject jobj, jshort js_handle, jshort js_timebase, jint ji_no_of_samples, jshort js_oversample, jobject jobj_timebase)
{
	//JNI variables
	///////////////
	jclass jc_timebase_info;

	jmethodID jmid_get_max_samples;
	jmethodID jmid_get_time_interval;
	jmethodID jmid_get_time_units;

	jmethodID jmid_set_max_samples;
	jmethodID jmid_set_time_interval;
	jmethodID jmid_set_time_units;

	// Other variables
	//////////////////
	jshort js_timebase_value;

	// Variables to hold the values from the Java Timebase Info object
	
	jint ji_max_samples = 0;
	jint ji_time_interval = 0;
	
	jshort js_time_units = 0;

	/*long max_samples = 1000;
	long time_interval = 0;
	short time_units = 1;*/


	// Get the values of the TimebaseInfo object via JNI

	//1. Retrieve the class reference
	if(isDebugModeOn)
	{
		printf("DEBUG: Retrieve the class reference\n");
	}

	jc_timebase_info = (*env)->GetObjectClass(env, jobj_timebase);
	
	if(isDebugModeOn)
	{
		printf("DEBUG: Obtain method identifiers\n");
	}

	//2. Obtain method identifiers

	jmid_get_max_samples = (*env)->GetMethodID(env, jc_timebase_info, "getMaxSamples", "()I");
	jmid_get_time_interval = (*env)->GetMethodID(env, jc_timebase_info, "getTimeInterval", "()I");
	jmid_get_time_units = (*env)->GetMethodID(env, jc_timebase_info, "getTimeUnits", "()S");

	jmid_set_max_samples = (*env)->GetMethodID(env, jc_timebase_info, "setMaxSamples", "(I)V");
	jmid_set_time_interval = (*env)->GetMethodID(env, jc_timebase_info, "setTimeInterval", "(I)V");
	jmid_set_time_units = (*env)->GetMethodID(env, jc_timebase_info, "setTimeUnits", "(S)V");

	// 3. Check if methods were found

	if(isDebugModeOn)
	{
		printf("DEBUG: Check if methods were found\n");
	}

	if(jmid_get_max_samples == 0)
	{
		printf("Can't find method getMaxSamples.\n");
		return 0;
	}

	if(jmid_get_time_interval == 0)
	{
		printf("Can't find method getTimeInterval.\n");
		return 0;
	}

	if(jmid_get_time_units == 0)
	{
		printf("Can't find method getTimeUnits.\n");
		return 0;
	}

	if(jmid_set_max_samples == 0)
	{
		printf("Can't find method setMaxSamples.\n");
		return 0;
	}

	if(jmid_set_time_interval == 0)
	{
		printf("Can't find method setTimeInterval.\n");
		return 0;
	}

	if(jmid_set_time_units == 0)
	{
		printf("Can't find method setTimeUnits.\n");
		return 0;
	}

	if(isDebugModeOn)
	{
		printf("DEBUG: Calling methods to get variables\n");
	}

	//4. Call methods but check for any exceptions
	(*env)->ExceptionClear(env);
	(*env)->CallIntMethod(env, jobj_timebase, jmid_get_max_samples, ji_max_samples);
	checkExceptionOccurred(env, "getMaxSamples");

	(*env)->CallIntMethod(env, jobj_timebase, jmid_get_time_interval, ji_time_interval);
	checkExceptionOccurred(env, "getTimeInterval");

	(*env)->CallShortMethod(env, jobj_timebase, jmid_get_time_units, js_time_units);
	checkExceptionOccurred(env, "getTimeUnits");

	//Assign values
	/*max_samples = ji_max_samples;
	time_interval = ji_time_interval;
	time_units = js_time_units;*/

	if(isDebugModeOn)
	{
		printf("DEBUG: Call the ps2000_get_timebase function\n");
	}

	// Call the ps2000_get_timebase function
	js_timebase_value = ps2000_get_timebase(js_handle, js_timebase, ji_no_of_samples, &ji_time_interval, &js_time_units, js_oversample, &ji_max_samples );

	if(isDebugModeOn)
	{
		printf("DEBUG: Set the values of the TimebaseInfo object\n");
	}

	// Set the values of the TimebaseInfo object
	(*env)->CallVoidMethod(env, jobj_timebase, jmid_set_max_samples, ji_max_samples);
	checkExceptionOccurred(env, "setMaxSamples");

	(*env)->CallVoidMethod(env, jobj_timebase, jmid_set_time_interval, ji_time_interval);
	checkExceptionOccurred(env, "setTimeInterval");

	(*env)->CallVoidMethod(env, jobj_timebase, jmid_set_time_units, js_time_units);
	checkExceptionOccurred(env, "getTimebase");

	if(isDebugModeOn)
	{
		printf("DEBUG: Timebase values from wrapper dll");
		printf("Max samples: %d\n", ji_max_samples);
		printf("Time interval: %d\n", ji_time_interval);
		printf("Time units: %d\n", js_time_units);
	}

	return js_timebase_value;
}

/**
*	Function to call ps2000_get_streaming_last_values
*
**/
//JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000PollFastStreaming
//  (JNIEnv * env, jobject jobj, jshort js_handle, jobject jobj_times_and_values)
//{
//	_ready = 0;
//
//	return ps2000_get_streaming_last_values(js_handle, (GetOverviewBuffersMaxMin) GetValuesCallback);
//}

/**
*	Function to call ps2000_ready
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000Ready
  (JNIEnv * env, jobject jobj, jshort js_handle)
{
	return ps2000_ready(js_handle);
}

/**
*	Function to call ps2000_run_block
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000RunBlock
  (JNIEnv * env, jobject jobj, jshort js_handle, jint ji_num_samples, jshort js_timebase, jshort js_oversample, jobject jobj_time_indisposed)
{
	jclass jc_time_indisposed;

	jmethodID jmid_get_time_indisposed;
	jmethodID jmid_set_time_indisposed;

	jshort js_run_block_status = 0;
	jint ji_time_indisposed_ms = 0;
	
	//Get class instance
	jc_time_indisposed = (*env)->GetObjectClass(env, jobj_time_indisposed);

	//Get method IDs
	jmid_get_time_indisposed = (*env)->GetMethodID(env, jc_time_indisposed, "getTimeIndisposed", "()I");
	jmid_set_time_indisposed = (*env)->GetMethodID(env, jc_time_indisposed, "setTimeIndisposed", "(I)V");

	//Check if method IDs returned
	
	if(jmid_get_time_indisposed == 0)
	{
		printf("Can't find method getTimeIndisposed.\n");
		return 0;
	}

	if(jmid_set_time_indisposed == 0)
	{
		printf("Can't find method setTimeIndisposed.\n");
		return 0;
	}

	// Call 'Get' method
	(*env)->ExceptionClear(env);
	(*env)->CallIntMethod(env, jobj_time_indisposed, jmid_get_time_indisposed, ji_time_indisposed_ms);
	checkExceptionOccurred(env, "getTimeIndisposed");

	js_run_block_status = ps2000_run_block(js_handle, ji_num_samples, js_timebase, js_oversample, &ji_time_indisposed_ms);

	// Call 'Set' method
	(*env)->CallVoidMethod(env, jobj_time_indisposed, jmid_set_time_indisposed, ji_time_indisposed_ms);
	checkExceptionOccurred(env, "setTimeIndisposed");

	return js_run_block_status;
}

/**
* Function to call ps2000_run_streaming for PicoScopes 2202, 2104 and 2105 only. 
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000RunStreaming
  (JNIEnv * env, jobject jobj, jshort js_handle, jshort js_sample_interval_ms, jint ji_max_samples, jshort js_windowed)
{
	return ps2000_run_streaming(js_handle, js_sample_interval_ms, ji_max_samples, js_windowed);
}

/**
* Function to call ps2000_run_streaming_ns for PicoScopes 2203, 2204 and 2205 ONLY. 
*
**/
//JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000RunStreamingNS
//(JNIEnv * env, jobject jobj, jshort js_handle, jint ji_sample_interval, jint ji_time_units, jint ji_max_samples, jshort js_auto_stop, jint ji_num_samples_per_aggregate, jint ji_overview_buffer_size)
//{
//	return ps2000_run_streaming_ns(js_handle, ji_sample_interval, ji_time_units, ji_max_samples, js_auto_stop, ji_num_samples_per_aggregate, ji_overview_buffer_size);
//}

/**
*	Function to call ps2000_set_channel
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000SetChannel
  (JNIEnv * env, jobject jobj, jshort js_handle, jshort js_channel, jshort js_enabled, jshort js_dc, jshort js_range)
{
	return ps2000_set_channel(js_handle, js_channel, js_enabled, js_dc, js_range);
}

/**
*	Function to call ps2000_set_ets
*
**/
JNIEXPORT jint JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000SetETS
  (JNIEnv * env, jobject jobj, jshort js_handle, jshort js_mode, jshort js_ets_cycles, jshort js_ets_interleave)
{
	return ps2000_set_ets(js_handle, js_mode, js_ets_cycles, js_ets_interleave);
}

/**
*	Function to call ps2000_set_light
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000SetLight
  (JNIEnv * env, jobject jobj, jshort js_handle, jshort js_state)
{
	return ps2000_set_light(js_handle, js_state);
}

/**
*	Function to call ps2000_set_sig_gen_built_in
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000SetSigGenBuiltIn
  (JNIEnv * env, jobject jobj, jshort js_handle, jint ji_offset_voltage, jint ji_pk_to_pk, 
  jshort js_waveType, jfloat jf_start_frequency, jfloat jf_stop_frequency, jfloat jf_increment, jfloat jf_dwell_time, 
  jshort js_sweep_type, jint ji_sweeps)
{
	return ps2000_set_sig_gen_built_in(js_handle, ji_offset_voltage, ji_pk_to_pk, js_waveType, jf_start_frequency,
		jf_stop_frequency, jf_increment, jf_dwell_time, js_sweep_type, ji_sweeps);
}

/**
*	Function to call ps2000_set_trigger
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000SetTrigger
  (JNIEnv * env, jobject jobj, jshort js_handle, jshort js_source, jshort js_threshold, jshort js_direction, jshort js_delay, jshort js_auto_trigger_ms)
{
	return ps2000_set_trigger(js_handle, js_source, js_threshold, js_direction, js_delay, js_auto_trigger_ms);
}


/**
*	Function to call ps2000_stop
*
**/
JNIEXPORT jshort JNICALL Java_com_picotech_picoscope_ps2000_PS2000JNIWrapAccessor_ps2000Stop
  (JNIEnv * env, jobject jobj, jshort js_handle)
{
	return ps2000_stop(js_handle);
}
